package #
Locale::Codes::LangVar_Retired;

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'deprecate_codes' is run.
#    Generated on: Mon Nov 25 10:41:49 EST 2013

use strict;
require 5.006;
use warnings;
use utf8;

our($VERSION);
$VERSION='3.28';

$Locale::Codes::Retired{'langvar'}{'alpha'}{'code'} = {
};

$Locale::Codes::Retired{'langvar'}{'alpha'}{'name'} = {
   q(slovene in bohorič alphabet) => [ q(bohoric), q(Slovene in Bohorič alphabet) ],
};


1;
